@@ -25,29 +25,27 @@ fn main() {
 }
 
 fn test_once(data: &[u8]) {
-    let broken_up: Vec<Hashed> = data
-        .chunks_exact(32)
-        .map(|v| v.try_into().unwrap())
-        .collect();
+    let broken_up: Vec<Hashed> = data.windows(32).map(|v| v.try_into().unwrap()).collect();
     let forest = Forest::new(InMemoryBackend::default());
     let mut tree = forest.open_tree([0; 32]).unwrap();
     for bytes in broken_up.iter() {
         let pre_count = tree.iter().count();
         dbg!(pre_count);
         tree.insert([0; 32], Bytes::copy_from_slice(bytes));
-        assert!(dbg!(tree.iter().count()) >= pre_count);
         assert!(tree
             .get_with_proof([0; 32])
             .1
             .verify(tree.root_hash(), [0; 32], bytes.as_ref()));
+        forest.delete_tree(tree.root_hash());
+        tree.save();
         tree.insert(*bytes, Bytes::copy_from_slice(bytes));
-        assert!(dbg!(tree.iter().count()) >= pre_count);
         let gotten = tree.get_with_proof(*bytes);
         assert_eq!(gotten.0.as_ref(), bytes.as_ref());
         assert!(tree
             .get_with_proof(*bytes)
             .1
             .verify(tree.root_hash(), *bytes, bytes.as_ref()));
+        // tree.save();
     }
     // for bytes in broken_up.iter() {
     //     let (val, proof) = tree.get_with_proof(*bytes);
